@@ -201,6 +201,10 @@ class ComicArchive:
 
         return page_list[index]
 
+    def is_image(self, name_path: Path) -> bool:
+        suffix_list = [".jpg", ".jpeg", ".png", ".gif", ".webp"]
+        return name_path.suffix.lower() in suffix_list and name_path.name[0] != "."
+
     def get_page_name_list(self, sort_list: bool = True) -> List[str]:
         """Returns a list of page names from an archive"""
 
@@ -217,10 +221,7 @@ class ComicArchive:
             self.page_list = []
             for name in files:
                 name_path = Path(name)
-                if (
-                    name_path.suffix.lower() in [".jpg", "jpeg", ".png", ".gif", "webp"]
-                    and name_path.name[0] != "."
-                ):
+                if self.is_image(name_path):
                     self.page_list.append(name)
 
         return self.page_list
@@ -243,10 +244,7 @@ class ComicArchive:
                 self.metadata = ComicInfoXml().metadata_from_string(raw_metadata)
 
             # validate the existing page list (make sure count is correct)
-            if (
-                len(self.metadata.pages) != 0
-                and len(self.metadata.pages) != self.get_number_of_pages()
-            ):
+            if len(self.metadata.pages) not in [0, self.get_number_of_pages()]:
                 # pages array doesn't match the actual number of images we're seeing
                 # in the archive, so discard the data
                 self.metadata.pages = []
