@@ -25,7 +25,7 @@ class IssueString:
             return
 
         # TODO: Once type hinting is finished for the project this check can be removed
-        if isinstance(text, int):
+        if isinstance(text, int) or isinstance(text, float):
             text = str(text)
 
         if len(text) == 0:
@@ -35,29 +35,9 @@ class IssueString:
         start: int = 1 if text[0] == "-" else 0
         # if it's still not numeric at start skip it
         if text[start].isdigit() or text[start] == ".":
-            # walk through the string, look for split point (the first
-            # non-numeric)
-            decimal_count: int = 0
-            for idx in range(start, len(text)):
-                if text[idx] not in "0123456789.":
-                    break
-                # special case: also split on second "."
-                if text[idx] == ".":
-                    decimal_count += 1
-                    if decimal_count > 1:
-                        break
-            else:
-                idx = len(text)
-
-            # move trailing numeric decimal to suffix
-            # (only if there is other junk after )
-            if text[idx - 1] == "." and len(text) != idx:
-                idx = idx - 1
-
-            # if there is no numeric after the minus, make the minus part of
-            # the suffix
-            if idx == 1 and start == 1:
-                idx = 0
+            idx = self.find_splitpoint(text, start)
+            idx = self.move_trailing_numeric_decimal_to_suffix(idx, text)
+            idx = self.determine_if_number_after_minus_sign(idx, start)
 
             part1 = text[0:idx]
             part2 = text[idx : len(text)]
@@ -68,7 +48,35 @@ class IssueString:
         else:
             self.suffix = text
 
-        # print "num: {0} suf: {1}".format(self.num, self.suffix)
+    def move_trailing_numeric_decimal_to_suffix(self, idx: int, text: str) -> int:
+        # move trailing numeric decimal to suffix (only if there is other junk after )
+        if text[idx - 1] == "." and len(text) != idx:
+            idx -= 1
+        return idx
+
+    def determine_if_number_after_minus_sign(self, idx: int, start: int) -> int:
+        # if there is no numeric after the minus, make the minus part of
+        # the suffix
+        if idx == 1 and start == 1:
+            return 0
+        else:
+            return idx
+
+    def find_splitpoint(self, text: str, start: int) -> int:
+        # walk through the string, look for split point (the first non-numeric)
+        decimal_count: int = 0
+        for idx in range(start, len(text)):
+            if text[idx] not in "0123456789.":
+                break
+            # special case: also split on second "."
+            if text[idx] == ".":
+                decimal_count += 1
+                if decimal_count > 1:
+                    break
+        else:
+            idx = len(text)
+
+        return idx
 
     def as_string(self, pad: int = 0) -> str:
         """Returns a string with left-side zero padding"""
